*before you install mLab Doppler Radar Tool,
please check if you already install PyQt5 or not.*

## install

### Raspberry Pi
for **Raspberry Pi**,please install PyQt5 as following.
In Raspbian Stretch Lite the following worked for:
```
$sudo apt-get update
$sudo apt-get install qt5-default pyqt5-dev pyqt5-dev-tools
$sudo python3 -m pip install mLab-WalkSpeed-Radar-Tool
``` 